summaryrefslogtreecommitdiff
path: root/Xi
diff options
context:
space:
mode:
authorPeter Hutterer <peter.hutterer@who-t.net>2009-08-24 09:48:00 +1000
committerPeter Hutterer <peter.hutterer@who-t.net>2009-08-27 14:24:51 +1000
commit903c3db1d1685bd855dceed9e7b92890743663e1 (patch)
tree7a89f7e26ccad43c924042a1037a9a1cfb9234d5 /Xi
parent8bfd23e144e51401e3756de9260a4811fcc59e91 (diff)
Xext: rename Xtst* to XTest*
This patch corrects a misnaming of XTest-related functions. The extension itself announces itself as XTEST. Xtst is the library name itself, but all library functions are prefixed by XTest. Same with the naming in the server. - Rename all *Xtst* functions to *XTest* for consistency with the library and in-server API. - Rename the "Xtst device" property to "XTEST device" for consistency with the extension naming. - Rename the device naming to "<master device name> XTEST device". The default xtest devices become "Virtual core XTEST pointer" and "Virtual core XTEST keyboard". Signed-off-by: Peter Hutterer <peter.hutterer@who-t.net>
Diffstat (limited to 'Xi')
-rw-r--r--Xi/xichangehierarchy.c66
-rw-r--r--Xi/xiproperty.c2
2 files changed, 34 insertions, 34 deletions
diff --git a/Xi/xiproperty.c b/Xi/xiproperty.c
index 0a47e31ee..024dc444b 100644
--- a/Xi/xiproperty.c
+++ b/Xi/xiproperty.c
@@ -51,7 +51,7 @@ static struct dev_properties
char *name;
} dev_properties[] = {
{0, XI_PROP_ENABLED},
- {0, XI_PROP_XTST_DEVICE},
+ {0, XI_PROP_XTEST_DEVICE},
{0, XATOM_FLOAT},
{0, ACCEL_PROP_PROFILE_NUMBER},
{0, ACCEL_PROP_CONSTANT_DECELERATION},
diff --git a/Xi/xichangehierarchy.c b/Xi/xichangehierarchy.c
index c123724b8..1a06e4555 100644
--- a/Xi/xichangehierarchy.c
+++ b/Xi/xichangehierarchy.c
@@ -141,7 +141,7 @@ int SProcXIChangeHierarchy(ClientPtr client)
int
ProcXIChangeHierarchy(ClientPtr client)
{
- DeviceIntPtr ptr, keybd, xtstptr, xtstkeybd;
+ DeviceIntPtr ptr, keybd, XTestptr, XTestkeybd;
xXIAnyHierarchyChangeInfo *any;
int required_len = sizeof(xXIChangeHierarchyReq);
char n;
@@ -189,7 +189,7 @@ ProcXIChangeHierarchy(ClientPtr client)
ptr->coreEvents = keybd->coreEvents = FALSE;
/* Allocate virtual slave devices for xtest events */
- rc = AllocXtstDevice(client, name, &xtstptr, &xtstkeybd,
+ rc = AllocXTestDevice(client, name, &XTestptr, &XTestkeybd,
ptr, keybd);
if (rc != Success)
{
@@ -203,10 +203,10 @@ ProcXIChangeHierarchy(ClientPtr client)
flags[ptr->id] |= XIMasterAdded;
flags[keybd->id] |= XIMasterAdded;
- ActivateDevice(xtstptr, FALSE);
- ActivateDevice(xtstkeybd, FALSE);
- flags[xtstptr->id] |= XISlaveAdded;
- flags[xtstkeybd->id] |= XISlaveAdded;
+ ActivateDevice(XTestptr, FALSE);
+ ActivateDevice(XTestkeybd, FALSE);
+ flags[XTestptr->id] |= XISlaveAdded;
+ flags[XTestkeybd->id] |= XISlaveAdded;
if (c->enable)
{
@@ -215,18 +215,18 @@ ProcXIChangeHierarchy(ClientPtr client)
flags[ptr->id] |= XIDeviceEnabled;
flags[keybd->id] |= XIDeviceEnabled;
- EnableDevice(xtstptr, FALSE);
- EnableDevice(xtstkeybd, FALSE);
- flags[xtstptr->id] |= XIDeviceEnabled;
- flags[xtstkeybd->id] |= XIDeviceEnabled;
+ EnableDevice(XTestptr, FALSE);
+ EnableDevice(XTestkeybd, FALSE);
+ flags[XTestptr->id] |= XIDeviceEnabled;
+ flags[XTestkeybd->id] |= XIDeviceEnabled;
}
/* Attach the XTest virtual devices to the newly
created master device */
- AttachDevice(NULL, xtstptr, ptr);
- AttachDevice(NULL, xtstkeybd, keybd);
- flags[xtstptr->id] |= XISlaveAttached;
- flags[xtstkeybd->id] |= XISlaveAttached;
+ AttachDevice(NULL, XTestptr, ptr);
+ AttachDevice(NULL, XTestkeybd, keybd);
+ flags[XTestptr->id] |= XISlaveAttached;
+ flags[XTestkeybd->id] |= XISlaveAttached;
xfree(name);
}
@@ -275,14 +275,14 @@ ProcXIChangeHierarchy(ClientPtr client)
if (rc != Success)
goto unwind;
- xtstptr = GetXtstDevice(ptr);
- rc = dixLookupDevice(&xtstptr, xtstptr->id, client,
+ XTestptr = GetXTestDevice(ptr);
+ rc = dixLookupDevice(&XTestptr, XTestptr->id, client,
DixDestroyAccess);
if (rc != Success)
goto unwind;
- xtstkeybd = GetXtstDevice(keybd);
- rc = dixLookupDevice(&xtstkeybd, xtstkeybd->id, client,
+ XTestkeybd = GetXTestDevice(keybd);
+ rc = dixLookupDevice(&XTestkeybd, XTestkeybd->id, client,
DixDestroyAccess);
if (rc != Success)
goto unwind;
@@ -341,26 +341,26 @@ ProcXIChangeHierarchy(ClientPtr client)
/* can't disable until we removed pairing */
keybd->spriteInfo->paired = NULL;
ptr->spriteInfo->paired = NULL;
- xtstptr->spriteInfo->paired = NULL;
- xtstkeybd->spriteInfo->paired = NULL;
+ XTestptr->spriteInfo->paired = NULL;
+ XTestkeybd->spriteInfo->paired = NULL;
- /* disable the remove the devices, xtst devices must be done first
+ /* disable the remove the devices, XTest devices must be done first
else the sprites they rely on will be destroyed */
- DisableDevice(xtstptr, FALSE);
- DisableDevice(xtstkeybd, FALSE);
+ DisableDevice(XTestptr, FALSE);
+ DisableDevice(XTestkeybd, FALSE);
DisableDevice(keybd, FALSE);
DisableDevice(ptr, FALSE);
- flags[xtstptr->id] |= XIDeviceDisabled | XISlaveDetached;
- flags[xtstkeybd->id] |= XIDeviceDisabled | XISlaveDetached;
+ flags[XTestptr->id] |= XIDeviceDisabled | XISlaveDetached;
+ flags[XTestkeybd->id] |= XIDeviceDisabled | XISlaveDetached;
flags[keybd->id] |= XIDeviceDisabled;
flags[ptr->id] |= XIDeviceDisabled;
- RemoveDevice(xtstptr, FALSE);
- RemoveDevice(xtstkeybd, FALSE);
+ RemoveDevice(XTestptr, FALSE);
+ RemoveDevice(XTestkeybd, FALSE);
RemoveDevice(keybd, FALSE);
RemoveDevice(ptr, FALSE);
- flags[xtstptr->id] |= XISlaveRemoved;
- flags[xtstkeybd->id] |= XISlaveRemoved;
+ flags[XTestptr->id] |= XISlaveRemoved;
+ flags[XTestkeybd->id] |= XISlaveRemoved;
flags[keybd->id] |= XIMasterRemoved;
flags[ptr->id] |= XIMasterRemoved;
}
@@ -381,8 +381,8 @@ ProcXIChangeHierarchy(ClientPtr client)
goto unwind;
}
- /* Don't allow changes to Xtst Devices, these are fixed */
- if (IsXtstDevice(ptr, NULL))
+ /* Don't allow changes to XTest Devices, these are fixed */
+ if (IsXTestDevice(ptr, NULL))
{
client->errorValue = c->deviceid;
rc = BadDevice;
@@ -410,8 +410,8 @@ ProcXIChangeHierarchy(ClientPtr client)
goto unwind;
}
- /* Don't allow changes to Xtst Devices, these are fixed */
- if (IsXtstDevice(ptr, NULL))
+ /* Don't allow changes to XTest Devices, these are fixed */
+ if (IsXTestDevice(ptr, NULL))
{
client->errorValue = c->deviceid;
rc = BadDevice;